/*
 * $Id: MockActionServlet.java 471754 2006-11-06 14:55:09Z husted $
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.struts.mock;

import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;

import org.apache.struts.action.ActionServlet;

/**
 * <p>Mock <strong>ActionServlet</strong> object for low-level unit tests of
 * Struts controller components.  Coarser grained tests should be implemented
 * in terms of the Cactus framework, instead of the mock object classes.</p>
 *
 * <p><strong>WARNING</strong> - Only getter methods for servletContext and
 * servletConfig are provided, plus additional methods to configure this
 * object as necessary.  Methods for unsupported operations will throw
 * <code>UnsupportedOperationException</code>.</p>
 *
 * <p><strong>WARNING</strong> - Because unit tests operate in a single
 * threaded environment, no synchronization is performed.</p>
 *
 * @version $Rev: 471754 $ $Date: 2005-05-14 02:09:06 -0400 (Sat, 14 May 2005)
 *          $
 */
public class MockActionServlet extends ActionServlet {

    /** serialVersionUID */
    private static final long serialVersionUID = 7761398622946832174L;

    private ServletContext servletContext;
    private ServletConfig servletConfig;

    /**
     * <p>Constructor.</p>
     * @param context ServletContext
     * @param config ServletConfig
     */
    public MockActionServlet(final ServletContext context, final ServletConfig config) {
        this.servletContext = context;
        this.servletConfig = config;
    }

    /**
     * <p>Constructor.</p>
     */
    public MockActionServlet() {
        return;
    }

    /**
     * <p> Set property </p>
     *
     * @param context ServletContext
     */
    public void setServletContext(final ServletContext context) {
        this.servletContext = context;
    }

    /**
     * <p> Get property </p>
     *
     * @return ServletContext
     */
    @Override
    public ServletContext getServletContext() {
        return this.servletContext;
    }

    /**
     * <p> Set property
     *
     * @param config ServletConfig
     */
    public void setServletConfig(final ServletConfig config) {
        this.servletConfig = config;
    }

    /**
     * <p> Get property </p>
     *
     * @return ServletConfig
     */
    @Override
    public ServletConfig getServletConfig() {
        return this.servletConfig;
    }

    /**
     * <p> Expose as public so that test classes can exercise things which
     * retrieve messages. </p>
     */
    public void initInternal() {
        return;
    }
}
